Description Usage Arguments Details Value Examples
Loudness Units Time Line from audo file. A lutl object is a timeline of sound levels with a resolution of tenths of a second. The data is obtained by processing an audio file with ffmpeg and the EBUR128 plug-in.
1 2 3 4 5 6 7 8 9 10 11 |
file |
Any file with an audio track that is consistent with ffmpeg |
skip_first_n |
Skip the first n observations. On at least one Sansa Fuze device, the first observations of the recorded audio are basically silent, so they can be ignored. |
start_date |
Date and time of the start of the audio recording. In case you do not set this parameter, it tries to retrieve the file name information, for now only valid for the devices with the rockbox firmware. |
from |
From "hour:minute:second" |
duration |
Length in "Hour:minute:second" |
group_by_n |
Each observation corresponds to one tenth of a second, with this parameter we can group them to reduce the final size of the data. Example 'group_by_n = 10' corresponds to one observation every second. |
adjfun |
Summation or adjustment function when grouping observations By default, 'mean' is used |
compact_fmt |
Use compact format? (default = TRUE) |
verbose |
default FALSE |
EBU R 128 is a recommendation for loudness normalisation and maximum level of audio signals. It is primarily followed during audio mixing of television and radio programmes and adopted by broadcasters to measure and control programme loudness. It was first issued by the European Broadcasting Union in August 2010 and most recently revised in June 2014. R 128 employs an international standard for measuring audio loudness, stated in the ITU-R BS.1770 recommendation and using the loudness measures LU (loudness units) and LUFS (loudness units referenced to full scale), specifically created with this purpose.[3] The EBU Tech 3341 document further clarified loudness metering implementation and practices in 2016.
a lutl object
1 2 3 4 5 | ## Not run:
data <- lutl_from_file('~/Descargas/ejemplo.wav')
data <- lutl_from_file('~/Descargas/ejemplo.wav', start_date = "2020-10-02 16:45:34")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.